aboutsummaryrefslogtreecommitdiffstats
path: root/extcap.h
diff options
context:
space:
mode:
Diffstat (limited to 'extcap.h')
-rw-r--r--extcap.h10
1 files changed, 8 insertions, 2 deletions
diff --git a/extcap.h b/extcap.h
index d066d9d2a9..9f398d1b5c 100644
--- a/extcap.h
+++ b/extcap.h
@@ -55,6 +55,8 @@ typedef struct _extcap_info {
gchar * basename;
gchar * full_path;
gchar * version;
+
+ GList * interfaces;
} extcap_info;
struct _extcap_arg;
@@ -83,9 +85,13 @@ append_extcap_interface_list(GList *list, char **err_str);
gchar *
extcap_get_help_for_ifname(const char *ifname);
/* get a list of all available extcap tools */
GHashTable *
-extcap_tools_list(void);
+extcap_loaded_interfaces(void);
+
+/* remove all loaded interfaces */
+void
+extcap_clear_interfaces(void);
/* returns the configuration for the given interface name, or an
* empty list, if no configuration has been found */
@@ -83,9 +85,13 @@ append_extcap_interface_list(GList *list, char **err_str);
gchar *
extcap_get_help_for_ifname(const char *ifname);
-/* get a list of all available extcap tools */
+/* get a list of all available extcap executables and their interfaces */
GHashTable *